searchData={"items":[{"type":"module","title":"PorscheConnEx.Client","doc":"Issues requests to the Porsche Connect API.","ref":"PorscheConnEx.Client.html"},{"type":"module","title":"Common arguments - PorscheConnEx.Client","doc":"All functions in this module require one of the following as their first argument:\n\n- a `PorscheConnEx.Session` process (by PID or by name)\n- a `PorscheConnEx.Session.RequestData` structure\n\nThis will both configure and authenticate the API call, based\non the starting arguments for the `PorscheConnEx.Session` process.\n\nMost calls require the [17-character\nVIN](https://en.wikipedia.org/wiki/Vehicle_identification_number) of the\nvehicle to be queried or altered.  This can be retrieved using\n`PorscheConnEx.Client.vehicles/1`.\n\nSeveral calls related to electric vehicles also require the vehicle model.\nThis can be retrieved using `PorscheConnEx.Client.capabilities/2`.","ref":"PorscheConnEx.Client.html#module-common-arguments"},{"type":"module","title":"Blocking & timeouts - PorscheConnEx.Client","doc":"The actual HTTP request will be performed in the calling process and will\nblock until complete.  While there is no explicit per-call timeout, the\neffective timeout can be influenced by setting `http_options` — see\n`PorscheConnEx.Config` for details.","ref":"PorscheConnEx.Client.html#module-blocking-timeouts"},{"type":"module","title":"Error values - PorscheConnEx.Client","doc":"The Porsche Connect API tends to be fairly opaque with server-side errors,\ngenerating the same \"unknown error\" result for most errors.  As a result, the\nmost common error value from this module will be `{:error, :unknown}`.\nHopefully, the cause of the error will be reasonably obvious based on\ncontext.\n\nLower-level errors will tend to be more descriptive.  These may include, but\nare not limited to, the following:\n\n- `{:error, :nxdomain}` - cannot find the API DNS name (are you offline?)\n- `{:error, :not_found}` - any \"404 Not Found\" HTTP error\n  - usually caused by choosing an unknown locale in your configuration\n- `{:error, :timeout}` - the HTTP request timed out\n\nHigher-level errors occur when the API call is successful, but this library\nreceives data that it cannot parse.  These are represented by `{:error,\nmap}`, where `map` is a nested map structure indicating which fields failed\nto parse and why.  Typically this falls into one of two categories: \n\n- An enum (atom) field received a value we haven't seen before\n- A value is marked as `required` but is unexpectedly `nil`\n\nIn these cases, I highly encourage users of this library to add the missing\nenum or remove the `required` and submit a pull request.  (We use these\nstrict data rules specifically so that we know the full range of values the\nAPI might return.)","ref":"PorscheConnEx.Client.html#module-error-values"},{"type":"function","title":"PorscheConnEx.Client.capabilities/2","doc":"Returns information about the capabilities of a particular vehicle.\n\nThis includes the model identifier, which is used in several other calls\nrelating to electric vehicle batteries and charging.","ref":"PorscheConnEx.Client.html#capabilities/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.capabilities/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#capabilities/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.capabilities/2","doc":"On success, returns `{:ok, capabs}`, where `capabs` is a\n`PorscheConnEx.Struct.Capabilities` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#capabilities/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.complete/2","doc":"Retrieves the final result of a pending request.\n\nSee `PorscheConnEx.Client.PendingRequest` for usage details.  Note that this\nfunction only applies to requests that read data, and will not match\nwrite-only requests.","ref":"PorscheConnEx.Client.html#complete/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.complete/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `pending` is a `PorscheConnEx.Client.PendingRequest` structure.","ref":"PorscheConnEx.Client.html#complete/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.complete/2","doc":"On success, returns `{:ok, result}`, where the nature of `result` depends on\nthe type of request being completed.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#complete/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.current_overview/2","doc":"Fetches current overview information about a particular vehicle.\n\nThe vehicle will be queried directly, and the information received should be\nfully up-to-date.  This may take a while, or fail, especially if the vehicle\nis turned off or has limited cellular signal.","ref":"PorscheConnEx.Client.html#current_overview/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.current_overview/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#current_overview/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.current_overview/2","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.\n\nTo wait for and retrieve the results, use `PorscheConnEx.Client.wait/3`.\nAlternatively, you may call `PorscheConnEx.Client.poll/2` and\n`PorscheConnEx.Client.complete/2` directly.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#current_overview/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.delete_charging_profile/4","doc":"Deletes a charging profile for an electric vehicle.","ref":"PorscheConnEx.Client.html#delete_charging_profile/4"},{"type":"function","title":"Arguments - PorscheConnEx.Client.delete_charging_profile/4","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be updated.\n- `model` is the model identifier of the vehicle to be updated.\n- `profile_id` is an integer indicating the slot to be deleted.\n\nFor details about the `profile_id` value, see\n`PorscheConnEx.Client.put_charging_profile/4`.\n\nNote that you probably shouldn't try to delete the \"General\" profile (#4), or\nany other non-user-defined profiles.  (I would assume you'd get an error if\nyou tried, but I'm not brave enough to find out.)","ref":"PorscheConnEx.Client.html#delete_charging_profile/4-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.delete_charging_profile/4","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.  See that structure's\ndocumentation for details.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#delete_charging_profile/4-return-values"},{"type":"function","title":"PorscheConnEx.Client.delete_timer/4","doc":"Deletes a timer for an electric vehicle.","ref":"PorscheConnEx.Client.html#delete_timer/4"},{"type":"function","title":"Arguments - PorscheConnEx.Client.delete_timer/4","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be updated.\n- `model` is the model identifier of the vehicle to be updated.\n- `timer_id` is an integer indicating the slot to be deleted.\n\nFor details about the `timer_id` value, see `PorscheConnEx.Client.put_timer/4`.","ref":"PorscheConnEx.Client.html#delete_timer/4-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.delete_timer/4","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.  See that structure's\ndocumentation for details.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#delete_timer/4-return-values"},{"type":"function","title":"PorscheConnEx.Client.emobility/3","doc":"Returns comprehensive data about the electric charging status and behaviour\nof a particular vehicle.","ref":"PorscheConnEx.Client.html#emobility/3"},{"type":"function","title":"Arguments - PorscheConnEx.Client.emobility/3","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.\n- `model` is the model identifier of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#emobility/3-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.emobility/3","doc":"On success, returns `{:ok, emob}`, where `emob` is a\n`PorscheConnEx.Struct.Emobility` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#emobility/3-return-values"},{"type":"function","title":"PorscheConnEx.Client.maintenance/2","doc":"Returns a list of maintenance events regarding a particular vehicle.","ref":"PorscheConnEx.Client.html#maintenance/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.maintenance/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#maintenance/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.maintenance/2","doc":"On success, returns `{:ok, list}`, where `list` is a list of\n`PorscheConnEx.Struct.Maintenance` structures.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#maintenance/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.poll/2","doc":"Checks the status of a pending request.\n\nSee `PorscheConnEx.Client.PendingRequest` for usage details.","ref":"PorscheConnEx.Client.html#poll/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.poll/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `pending` is a `PorscheConnEx.Client.PendingRequest` structure.","ref":"PorscheConnEx.Client.html#poll/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.poll/2","doc":"- Returns `{:ok, :in_progress}` if the request is still ongoing.\n- Returns `{:ok, :success}` if the request completed successfully.\n- Returns `{:error, :failed}` if the request failed.\n- Returns `{:error, _}` on other errors.","ref":"PorscheConnEx.Client.html#poll/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.position/2","doc":"Returns the current global position of a particular vehicle.","ref":"PorscheConnEx.Client.html#position/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.position/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#position/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.position/2","doc":"On success, returns `{:ok, position}`, where `position` is a\n`PorscheConnEx.Struct.Position` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#position/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.put_charging_profile/4","doc":"Creates or updates a charging profile for an electric vehicle.\n\nCharging profiles define basic charging parameters, such as charging targets,\npreferred charging hours, etc.  They can also be tied to a specific\ngeographical location, such as a home or office, in which case they will\nautomatically de/activate based on the vehicle's location.","ref":"PorscheConnEx.Client.html#put_charging_profile/4"},{"type":"function","title":"Arguments - PorscheConnEx.Client.put_charging_profile/4","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be updated.\n- `model` is the model identifier of the vehicle to be updated.\n- `profile` is a `PorscheConnEx.Struct.Emobility.ChargingProfile` structure.","ref":"PorscheConnEx.Client.html#put_charging_profile/4-arguments"},{"type":"function","title":"Profile slots - PorscheConnEx.Client.put_charging_profile/4","doc":"There are a limited number of slots available for charging profiles,\nidentified by the `profile.id` field.  From testing to date, it appears that\nprofile #4 is the \"General\" (default) profile, and profiles 5 through 7 are\n\"local\" (user-defined) profiles.\n\nIf `profile` has a non-nil `id` value, then it will overwrite that slot.\n\nIf `profile` has a nil `id` value, then it will be placed in the first empty\n\"local\" slot.  If no such slots are available, this function will return an\nerror.","ref":"PorscheConnEx.Client.html#put_charging_profile/4-profile-slots"},{"type":"function","title":"Return values - PorscheConnEx.Client.put_charging_profile/4","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.  See that structure's\ndocumentation for details.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#put_charging_profile/4-return-values"},{"type":"function","title":"PorscheConnEx.Client.put_timer/4","doc":"Creates or updates a timer for an electric vehicle.\n\nTimers are used to schedule charging, and/or to climatise (preheat/cool) the\nvehicle, e.g. in preparation for an upcoming trip.","ref":"PorscheConnEx.Client.html#put_timer/4"},{"type":"function","title":"Arguments - PorscheConnEx.Client.put_timer/4","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be updated.\n- `model` is the model identifier of the vehicle to be updated.\n- `timer` is a `PorscheConnEx.Struct.Emobility.Timer` structure.","ref":"PorscheConnEx.Client.html#put_timer/4-arguments"},{"type":"function","title":"Timer slots - PorscheConnEx.Client.put_timer/4","doc":"There are five slots available for timers, identified by the `timer.id` field.\nIf `timer` has a non-nil `id` value, then it will overwrite that slot.\n\nIf `timer` has a nil `id` value, then it will be placed in the first\nempty slot.  If no slots are available, this function will return an error.","ref":"PorscheConnEx.Client.html#put_timer/4-timer-slots"},{"type":"function","title":"Return values - PorscheConnEx.Client.put_timer/4","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.  See that structure's\ndocumentation for details.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#put_timer/4-return-values"},{"type":"function","title":"PorscheConnEx.Client.set_climate/3","doc":"Starts or cancels the \"direct climatisation\" (preheat/cool) feature.","ref":"PorscheConnEx.Client.html#set_climate/3"},{"type":"function","title":"Arguments - PorscheConnEx.Client.set_climate/3","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be updated.\n- `on_off` is a boolean indicating whether to turn on climatisation (`true`) or turn it off (`false`).","ref":"PorscheConnEx.Client.html#set_climate/3-arguments"},{"type":"function","title":"Climatisation timer - PorscheConnEx.Client.set_climate/3","doc":"When climatisation is off, turning it on will enable it for the next 60\nminutes, after which time it will automatically turn off again.\n\nIf climatisation is already in the indicated state, no action will occur, and\nthis timer will not be reset.","ref":"PorscheConnEx.Client.html#set_climate/3-climatisation-timer"},{"type":"function","title":"Return values - PorscheConnEx.Client.set_climate/3","doc":"On success, returns `{:ok, pending}`, where `pending` is a\n`PorscheConnEx.Client.PendingRequest` structure.  See that structure's\ndocumentation for details.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#set_climate/3-return-values"},{"type":"function","title":"PorscheConnEx.Client.status/2","doc":"Returns general status information about a particular vehicle.","ref":"PorscheConnEx.Client.html#status/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.status/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#status/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.status/2","doc":"On success, returns `{:ok, status}`, where `status` is a\n`PorscheConnEx.Struct.Status` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#status/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.stored_overview/2","doc":"Returns recent overview information about a particular vehicle.\n\nThe vehicle is not queried directly; instead, this call retrieves data stored\nserver-side about the vehicle, based on the vehicle's most recent update.","ref":"PorscheConnEx.Client.html#stored_overview/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.stored_overview/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#stored_overview/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.stored_overview/2","doc":"On success, returns `{:ok, overview}`, where `overview` is a\n`PorscheConnEx.Struct.Overview` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#stored_overview/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.summary/2","doc":"Returns extremely basic information about a particular vehicle.","ref":"PorscheConnEx.Client.html#summary/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.summary/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#summary/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.summary/2","doc":"On success, returns `{:ok, summary}`, where `summary` is a\n`PorscheConnEx.Struct.Summary` structure.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#summary/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.trips_long_term/2","doc":"Returns a list of long-term trips taken by a particular vehicle.\n\nThese trips are generated when the user clears the short-term trip list.  The\nmost recent one should be a summary of all the short-term trips.","ref":"PorscheConnEx.Client.html#trips_long_term/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.trips_long_term/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#trips_long_term/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.trips_long_term/2","doc":"On success, returns `{:ok, list}`, where `list` is a list of\n`PorscheConnEx.Struct.Trip` structures.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#trips_long_term/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.trips_short_term/2","doc":"Returns a list of short-term trips taken by a particular vehicle.\n\nThese trips are automatically generated, presumably based on when the vehicle\nis turned on/off, parked, etc.","ref":"PorscheConnEx.Client.html#trips_short_term/2"},{"type":"function","title":"Arguments - PorscheConnEx.Client.trips_short_term/2","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `vin` is the VIN of the vehicle to be queried.","ref":"PorscheConnEx.Client.html#trips_short_term/2-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.trips_short_term/2","doc":"On success, returns `{:ok, list}`, where `list` is a list of\n`PorscheConnEx.Struct.Trip` structures.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#trips_short_term/2-return-values"},{"type":"function","title":"PorscheConnEx.Client.vehicles/1","doc":"Returns a list of vehicles assigned to the current account.","ref":"PorscheConnEx.Client.html#vehicles/1"},{"type":"function","title":"Arguments - PorscheConnEx.Client.vehicles/1","doc":"","ref":"PorscheConnEx.Client.html#vehicles/1-arguments"},{"type":"function","title":"Arguments - PorscheConnEx.Client.vehicles/1","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.","ref":"PorscheConnEx.Client.html#vehicles/1-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.vehicles/1","doc":"On success, returns `{:ok, list}`, where `list` is a list of\n`PorscheConnEx.Struct.Vehicle` structures.\n\nOn error, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#vehicles/1-return-values"},{"type":"function","title":"PorscheConnEx.Client.wait/3","doc":"Polls a pending request until it finishes, then completes it if applicable.\n\nSee `PorscheConnEx.Client.PendingRequest` for usage details.","ref":"PorscheConnEx.Client.html#wait/3"},{"type":"function","title":"Arguments - PorscheConnEx.Client.wait/3","doc":"- `session` is a `PorscheConnEx.Session` pid/name or a\n  `PorscheConnEx.Session.RequestData` structure.\n- `pending` is a `PorscheConnEx.Client.PendingRequest` structure.\n- `opts` is a keyword-list of options and their values:\n  - `count` (default: 120) is the maximum number of times to poll before giving up.\n  - `delay` (default: 1000) is the delay (in milliseconds) to wait between poll attempts.","ref":"PorscheConnEx.Client.html#wait/3-arguments"},{"type":"function","title":"Return values - PorscheConnEx.Client.wait/3","doc":"If the request ultimately finishes successfully, returns `{:ok, result}`,\nwhere the nature of `result` depends on the type of request being completed.\n(For write-only operations, `result` will just be `:success`, as per the return\nvalue of `poll/2`.)\n\nIf the request fails, returns `{:error, :failed}` as per the return value of `poll/2`.\n\nIf the result is still pending after `count` polls, returns `{:error,\n:in_progress}`.  You may call `poll/2` or `wait/2` again if you still want to\ncontinue waiting.\n\nOn other errors, returns `{:error, _}`.","ref":"PorscheConnEx.Client.html#wait/3-return-values"},{"type":"type","title":"PorscheConnEx.Client.model/0","doc":"","ref":"PorscheConnEx.Client.html#t:model/0"},{"type":"type","title":"PorscheConnEx.Client.vin/0","doc":"","ref":"PorscheConnEx.Client.html#t:vin/0"},{"type":"type","title":"PorscheConnEx.Client.wait_option/0","doc":"","ref":"PorscheConnEx.Client.html#t:wait_option/0"},{"type":"type","title":"PorscheConnEx.Client.wait_options/0","doc":"","ref":"PorscheConnEx.Client.html#t:wait_options/0"},{"type":"module","title":"PorscheConnEx.Client.PendingRequest","doc":"Return value from API calls that may take a long time to complete.\n\nSome `PorscheConnEx.Client` calls will return `{:ok, %PendingRequest{...}}`\nto indicate that their request has been accepted but not necessarily\ncompleted yet.  To determine the eventual fate of the request, see below.","ref":"PorscheConnEx.Client.PendingRequest.html"},{"type":"module","title":"For write requests - PorscheConnEx.Client.PendingRequest","doc":"Once a write request has been submitted, no further action is required on\nthe part of the library user — if possible, the requested action will be\nsend and performed on the vehicle. However, if the vehicle cannot be\nreached within a certain amount of time, the call will ultimately fail, and\nnothing will happen.\n\nTo discover the fate of your request, you can use one of two approaches:\n\n- call `PorscheConnEx.Client.poll/2` repeatedly to check the status of the\n  request, waiting for a status other than `:in_progress`\n- call `PorscheConnEx.Client.wait/3` to do the above for you, polling\n  repeatedly until it receives a status other than `:in_progress`\n\nNote that, in some cases, you may not care about what happens to the\nrequest.  For example, if your code is periodically checking\n`PorscheConnEx.Client.emobility/3` and updating timers and/or charging profiles\nbased on that data, then it may be fine to just \"fire and forget\" requests,\nsince any failures will presumably be noticed and retried on the next check.","ref":"PorscheConnEx.Client.PendingRequest.html#module-for-write-requests"},{"type":"module","title":"For read requests - PorscheConnEx.Client.PendingRequest","doc":"There is currently only one read request that uses pending requests —\n`PorscheConnEx.Client.current_overview/2`.  Obviously, it would not make\nsense to just leave this request pending, since the whole point is to\nretrieve the most recent vehicle overview data.\n\nRead requests differ from write requests in that, once the request has\nsucceeded, there is an extra call required to retrieve the final output\ndata.  As such, there are two possible approaches:\n\n- call `PorscheConnEx.Client.poll/2` repeatedly to check the status of the\n  request until you get a status other than `:in_progress`, then run\n  `PorscheConnEx.Client.complete/2` to retrieve the final results (but only\n  if the status is `:success`)\n- call `PorscheConnEx.Client.wait/3` to do all of the above for you — i.e.\n  polling repeatedly until it receives a status other than `:in_progress`,\n  then retrieving the final results for you (if status is `:success`)\n\nNote that `PorscheConnEx.Client.complete/2` will **not** prevent you from\ntrying to retrieve the final results of a failed or still-in-progress\nrequest, but the results will almost certainly fail to parse due to missing\ndata.  Wait for a poll result of `:success` first.","ref":"PorscheConnEx.Client.PendingRequest.html#module-for-read-requests"},{"type":"type","title":"PorscheConnEx.Client.PendingRequest.handler/0","doc":"","ref":"PorscheConnEx.Client.PendingRequest.html#t:handler/0"},{"type":"type","title":"PorscheConnEx.Client.PendingRequest.t/0","doc":"","ref":"PorscheConnEx.Client.PendingRequest.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Config","doc":"Configures the region and behaviour of the API session.","ref":"PorscheConnEx.Config.html"},{"type":"module","title":"Fields - PorscheConnEx.Config","doc":"- `language` (default `de`) - a two-letter language code\n- `country` (default `DE`) - a two-letter country code\n- `timezone` (default `Etc/UTC`) - a [timezone identifier](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones)\n- `api_url` (default `https://api.porsche.com`) - the base URL to access the Porsche Connect API\n- `http_options` (default `[]`) - a list of options accepted by `Req.new/1`","ref":"PorscheConnEx.Config.html#module-fields"},{"type":"module","title":"Locales - PorscheConnEx.Config","doc":"The `language` and `country` fields, when put together, should form a valid [locale name](https://en.wikipedia.org/wiki/Locale_(computer_software)).\n\nThe chosen locale may affect various aspects of the API.  The most obvious\neffect is to choose the units used (metric versus imperial).\n\nThe following locales are known to work:\n\n- `de_DE` (Germany) - metric units\n- `en_US` (United States) - imperial units\n\nThe following locales are known to **NOT** work:\n\n- `en_CA` (Canada)\n\nWhen choosing an unsupported locale, the initial authentication will succeed,\nbut most other requests will fail with `{:error, :not_found}`.\n\nNote that this library was designed and tested using `de_DE` (and also\ndefaults to this), on the assumption that German would be the most logical\nlocale for a German car. Some effort has been made to test against `en_US`\nand imperial units as well, but there may still be bugs when working in\nnon-German locales.","ref":"PorscheConnEx.Config.html#module-locales"},{"type":"function","title":"PorscheConnEx.Config.new/1","doc":"Creates a new configuration object.\n\n`opts` can be a `Keyword` list, a `Map`, or any other enumerable containing\nkey-value tuples.\n\nIt can also be an existing `PorscheConnEx.Config` structure, which will be\nreturned verbatim.","ref":"PorscheConnEx.Config.html#new/1"},{"type":"type","title":"PorscheConnEx.Config.t/0","doc":"","ref":"PorscheConnEx.Config.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Session","doc":"Handles configuration and authentication of an API session.\n\nStarting a session will acquire an access token from the Porsche Connect API\nat startup, and then acquire a new token whenever the current token is\nnearing expiry.  It also serves as stateful storage of the\n`PorscheConnEx.Config` structure used to configure the session.\n\nAll `PorscheConnEx.Client` calls require both HTTP authentication headers and\nthe `PorscheConnEx.Config` structure, which are bundled together into a\n`PorscheConnEx.Session.RequestData` structure.","ref":"PorscheConnEx.Session.html"},{"type":"function","title":"PorscheConnEx.Session.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PorscheConnEx.Session.html#child_spec/1"},{"type":"function","title":"PorscheConnEx.Session.request_data/1","doc":"Returns a session's configuration and authentication details.","ref":"PorscheConnEx.Session.html#request_data/1"},{"type":"function","title":"Arguments - PorscheConnEx.Session.request_data/1","doc":"- `pid_or_rdata` can be either\n  - the PID of a running `Session` process,\n  - the registered name of a running `Session` process, or\n  - an existing `PorscheConnEx.Session.RequestData` structure.","ref":"PorscheConnEx.Session.html#request_data/1-arguments"},{"type":"function","title":"Return value - PorscheConnEx.Session.request_data/1","doc":"Returns a `PorscheConnEx.Session.RequestData` structure containing the\nstarting configuration and current authentication details associated with the\nsession.\n\nIf given an existing `RequestData` structure, then that structure will be\nreturned verbatim.  This means that `PorscheConnEx.Client` calls can all\neffectively also receive a `RequestData` structure as their first argument,\nin lieu of a running session.  (This is used in e.g.\n`PorscheConnEx.Client.wait/2` to avoid unnecessary requests.)\n\nBeware that authentication tokens do expire, and you should not use a given\n`RequestData` structure for more than a few minutes before fetching another.","ref":"PorscheConnEx.Session.html#request_data/1-return-value"},{"type":"function","title":"PorscheConnEx.Session.start_link/1","doc":"Starts a session and authenticates with the API.","ref":"PorscheConnEx.Session.html#start_link/1"},{"type":"function","title":"Options - PorscheConnEx.Session.start_link/1","doc":"* `credentials` (required) - a keyword list or map containing\n    * `username` (required) - your Porsche Connect username\n    * `password` (required) - your Porsche Connect password\n  * `config` (optional) - a keyword list, a map, or a `PorscheConnEx.Config` structure\n    * see that module for fields and other details\n\nThis function also accepts all the options accepted by `GenServer.start_link/3`.","ref":"PorscheConnEx.Session.html#start_link/1-options"},{"type":"function","title":"Return values - PorscheConnEx.Session.start_link/1","doc":"Same as `GenServer.start_link/3`.  Note that this function will block until\nthe initial API authentication is complete.","ref":"PorscheConnEx.Session.html#start_link/1-return-values"},{"type":"type","title":"PorscheConnEx.Session.t/0","doc":"","ref":"PorscheConnEx.Session.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Session.RequestData","doc":"Structure containing the necessary data to perform API calls.\n\nCreated and returned by `PorscheConnEx.Session.request_data/1`.","ref":"PorscheConnEx.Session.RequestData.html"},{"type":"module","title":"Fields - PorscheConnEx.Session.RequestData","doc":"- `config` — a `PorscheConnEx.Config` structure containing API configuration\n- `headers` — a `Map` of HTTP authentication headers\n\nBy altering this structure, you can, in theory, authenticate with the API\nusing one configuration, then make calls with a different configuration.\nI'm not sure why you'd do this, though, and I wouldn't recommend it — some\naspects of the API are defined at authentication rather than per-request.","ref":"PorscheConnEx.Session.RequestData.html#module-fields"},{"type":"type","title":"PorscheConnEx.Session.RequestData.t/0","doc":"","ref":"PorscheConnEx.Session.RequestData.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Capabilities","doc":"Structure containing information about the capabilities of a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.capabilities/2`.","ref":"PorscheConnEx.Struct.Capabilities.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Capabilities","doc":"- `car_model` (string) — the vehicle platform code (e.g. \"J1\" for the Taycan)\n- `engine_type` (string) — the type of propulsion system (e.g. \"BEV\")\n- `has_rdk?` (boolean) — whether the vehicle features the RDK tire pressure monitoring system\n- `has_dx1?` (boolean) — unknown\n- `needs_spin?` (boolean) — unknown\n- `display_parking_brake?` (boolean) — unknown\n- `steering_wheel` (atom) — is the steering wheel on the `:left` or `:right` side?\n- `heating` (struct) — indicates the presence of seat heaters\n  - `front_seat?` (boolean) — whether the front seats can be heated\n  - `rear_seat?` (boolean) — whether the rear seats can be heated","ref":"PorscheConnEx.Struct.Capabilities.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Capabilities.heating/0","doc":"","ref":"PorscheConnEx.Struct.Capabilities.html#t:heating/0"},{"type":"type","title":"PorscheConnEx.Struct.Capabilities.steering_wheel_position/0","doc":"","ref":"PorscheConnEx.Struct.Capabilities.html#t:steering_wheel_position/0"},{"type":"type","title":"PorscheConnEx.Struct.Capabilities.t/0","doc":"","ref":"PorscheConnEx.Struct.Capabilities.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility","doc":"Structure containing information about the electric charging status and\nbehaviour of a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.emobility/3`.\n\nNote that there is some overlap between this structure, `PorscheConnEx.Struct.Status`, and `PorscheConnEx.Struct.Overview`.","ref":"PorscheConnEx.Struct.Emobility.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility","doc":"- `charging` ([`Emobility.ChargeStatus`](`Elixir.PorscheConnEx.Struct.Emobility.ChargeStatus`)) — information about the vehicle's charging status\n  - contains 17 sub-fields\n- `direct_charge` ([`Emobility.DirectCharge`](`Elixir.PorscheConnEx.Struct.Emobility.DirectCharge`)) — info about the vehicle's \"Direct Charge\" setting\n  - contains 2 sub-fields\n- `direct_climate` ([`Emobility.DirectClimate`](`Elixir.PorscheConnEx.Struct.Emobility.DirectClimate`)) — info about the vehicle's pre-heat/cool setting\n  - contains 5 sub-fields\n- `timers` (list of [`Emobility.Timer`](`Elixir.PorscheConnEx.Struct.Emobility.Timer`)s) — all charging/climatisation timers (user-created)\n- `charging_profiles` (list of [`Emobility.ChargingProfile`](`Elixir.PorscheConnEx.Struct.Emobility.ChargingProfile`)s) — all charging profiles (built-in and user-created)\n- `current_charging_profile` ([`Emobility.ChargingProfile`](`Elixir.PorscheConnEx.Struct.Emobility.ChargingProfile`)) — the currently active charging profile\n\nFor a list of sub-fields, see the relevant module documentation.","ref":"PorscheConnEx.Struct.Emobility.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.ChargeStatus","doc":"Structure containing information about the electric charging status of a\nparticular vehicle.","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.ChargeStatus","doc":"- `mode` (atom) — the current charging mode — `:off`, `:ac`, `:dc`, or `:unknown`\n  - `:dc` is currently speculative; I have not tested the API while hooked up to a DC Fast Charger.\n- `plug` (atom) — the status of the physical charging plug — `:connected` or `:disconnected`\n- `plug_lock` (atom) — the lock status of the charging plug — `:locked` or `:unlocked`\n- `state` (atom) — the current charging state — `:off`, `:charging`, `:completed`, or `:error`\n- `reason` (atom or tuple) — the reason for the current charging state\n  - `:immediate` if charging due to \"direct charge\" / user request / etc\n  - `{:timer, n}` if charging due to an upcoming timer in slot `n`\n  - `:invalid` if there is no reason to charge / charging negotiation is in progess / etc\n  - Note that if there is no immediate charging / climatisation activity, this value is unreliable — the API tends to return `{:timer, 4}`, regardless of whether timer #4 is the next timer or not.\n- `external_power` (atom) — the status of the external power connection\n  - `:station_connected` when connected to a charging station but not actively drawing power\n  - `:available` when actively drawing power from a charging station\n  - `:unavailable` when not connected to a charging station\n- `led_color` (atom) — the charging LED colour — `:white`, `:green`, `:blue`, `:red`, or `:off`\n- `led_state` (atom) — the charging LED state — `:flash`, `:blink`, `:pulse`, `:solid`, or `:off`\n- `percent` (integer) — the current percentage of charge (0 to 100)\n- `minutes_to_full` (integer) — the estimated number of minutes until target charge is reached\n  - Note that the API appears to calculate this value only when charging parameters change, meaning it will be valid at the start of a charge, but will remain the same (and become quite out of date) until suddenly dropping to zero when charging is complete.\n- `remaining_electric_range` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the estimated remaining electric travel range\n- `remaining_conventional_range` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the estimated remaining conventional travel range\n- `rate` ([`ChargeRate`](`Elixir.PorscheConnEx.Struct.Unit.ChargeRate`)) — the current charge rate, in terms of range increase over time\n- `kilowatts` (float) — the current charge rate, in kilowatts\n- `dc_mode?` (boolean) — whether the vehicle is charging in DC mode\n  - This appears to refer to DC power, not Direct Charging.  More research needed.\n  - If this is redundant due to `mode` above, then I'll remove it.\n- `target_time` (`NaiveDateTime`) — the local time that the vehicle intends to complete its next charge\n- `target_time_opl_enforced` (unknown) — has always been `nil` in testing\n  - Sounds like it may be a boolean?","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.external_power/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:external_power/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.led_color/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:led_color/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.led_state/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:led_state/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.mode/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:mode/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.plug/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:plug/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.plug_lock/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:plug_lock/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.reason/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:reason/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.state/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:state/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargeStatus.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargeStatus.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.ChargingProfile","doc":"Structure describing a vehicle charging profile.\n\nCharging profiles define basic charging parameters, such as charging targets,\npreferred charging hours, etc.  They can also be tied to a specific\ngeographical location, such as a home or office, in which case they will\nautomatically de/activate based on the vehicle's location.","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.html"},{"type":"module","title":"API calls - PorscheConnEx.Struct.Emobility.ChargingProfile","doc":"- To create or update a charging profile, use `PorscheConnEx.Client.put_charging_profile/4`.\n- To delete a charging profile, use `PorscheConnEx.Client.delete_charging_profile/4`.","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.html#module-api-calls"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.ChargingProfile","doc":"- `id` (integer) — the ID (slot number) of the charging profile\n  - The default built-in profile is slot #4.\n  - User-created profiles are in slots 5 through 7.\n- `name` (string) — the display name of the profile\n  - The default profile is named \"Allgemein\" (German for \"General\"), regardless of [locale settings](`PorscheConnEx.Config`).\n- `enabled?` (boolean) — whether the charging profile is enabled or not\n  - This **only** indicates whether the profile can be used, not whether it's currently selected.\n- `charging` ([`Emobility.ChargingProfile.ChargingOptions`](`Elixir.PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions`)) — the desired charging behaviour while this profile is active\n  - contains 4 sub-fields\n- `position` ([`Emobility.ChargingProfile.Position`](`Elixir.PorscheConnEx.Struct.Emobility.ChargingProfile.Position`) or `nil`) — the geographical location at which to activate the profile (if set)\n  - contains 3 sub-fields","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.id/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.html#t:id/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions","doc":"Structure containing desired charging behaviour for a particular profile.","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions","doc":"- `minimum_charge` (integer) — charge immediately if below this charge percentage (0 to 100)\n- `mode` (atom) — determines how the profile decides when to charge\n  - when set to `:smart`, the vehicle will negotiate the best charging time with the charger\n  - when set to `:preferred_time`, the vehicle will try to charge between the hours below\n- `preferred_time_start` (`Time`) — the start of the preferred hours (each day)\n- `preferred_time_end` (`Time`) — the end of the preferred hours (each day)\n\nIf `preferred_time_end` is later in the day than `preferred_time_start`, then\ncharging will occur between the two times.\n\nIf `preferred_time_end` is earlier in the day than `preferred_time_start`,\nthen this indicates an overnight charging period, and the preferred hours\nwill be any time later than `preferred_start_end` or earlier than\n`preferred_time_start`.","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.html#module-fields"},{"type":"module","title":"Charging behaviour - PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions","doc":"When plugged in, if the vehicle charge is below `minimum_charge`, charging\nwill begin immediately.  (This also occurs if `minimum_charge` is ever raised\nabove the vehicle's current charge.)\n\nOnce the minimum charge is reached, the vehicle will choose when (and how\nmuch) to charge based on the preferred hours and the next upcoming\n[timer](`PorscheConnEx.Struct.Emobility.Timer`) that has `charge?` set to `true`.\nThis timer will define the target charge level and the time at which that\ncharge should be achieved, while the preferred hours help define when the\nactual charging will occur.\n\nIf the next timer occurs during the preferred hours, then the timer will\nexecute normally — charging will start some time before the `depart_time`,\nbased on how long the vehicle expects charging to take.\n\nIf the next timer occurs outside of the preferred hours, then the vehicle\nwill start charging some time before `preferred_time_end`, and attempt to\nreach `target_charge` by the time preferred hours end.\n\nCurrent unknowns (more testing needed):\n\n- If the vehicle is used after the end of preferred hours, but before a timer,\n  and the vehicle no longer meets the requested `target_charge`, will the vehicle\n  \"top up\" outside of preferred hours, or just fail to meet the charge target?\n- If preferred hours end at 6am, and you have a timer at 8am that requests\n  70% charge, and a timer at 10am that requests 80% charge, will it \"look\n  ahead\" and charge to 80% by 6am, or just 70%?","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.html#module-charging-behaviour"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.mode/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.html#t:mode/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.ChargingOptions.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.Position","doc":"Structure containing the geographical location at which to activate a\nparticular profile.","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.Position.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.ChargingProfile.Position","doc":"- `latitude` (float) — geographical latitude\n- `longitude` (float) — geographical longitude\n- `radius` (integer) — maximum distance from the given lat/long within which to activate the profile","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.Position.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.ChargingProfile.Position.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.ChargingProfile.Position.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.DirectCharge","doc":"Structure containing information about the \"Direct Charge\" setting of a\nparticular vehicle.","ref":"PorscheConnEx.Struct.Emobility.DirectCharge.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.DirectCharge","doc":"- `disabled?` (boolean) — whether direct charging is disabled\n  - The reasons this feature might be disabled (or disallowed?) are unknown.\n- `active?` (boolean) — whether direct charging is currently active\n  - This indicates whether the \"Direct Charge\" setting has been activated by\n    the user, and not necessarily whether the vehicle is actually charging.","ref":"PorscheConnEx.Struct.Emobility.DirectCharge.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.DirectCharge.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.DirectCharge.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.DirectClimate","doc":"Structure containing information about the pre-heat/cool setting of a\nparticular vehicle.","ref":"PorscheConnEx.Struct.Emobility.DirectClimate.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.DirectClimate","doc":"- `state` (atom) — the current climatisation state — `:on` or `:off`\n- `remaining_minutes` — the remaining time before climatisation will shut down\n  - When triggered by a timer, this will be the minutes until the timer is reached.\n  - When manually enabled by the user, this will start at 60 minutes.\n- `target_temperature` ([`Temperature`](`Elixir.PorscheConnEx.Struct.Unit.Temperature`)) — the temperature that the cabin will be heated/cooled to\n- `heater_source` (atom) — the source of heat for pre-heating\n  - `:electric` is the only known value so far.\n- `without_hv_power?` (boolean) — unknown\n  - This might refer to whether the vehicle is pulling power from a charging\n    station (or the 12V standard car battery?) rather than from the HV battery.","ref":"PorscheConnEx.Struct.Emobility.DirectClimate.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.DirectClimate.heater_source/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.DirectClimate.html#t:heater_source/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.DirectClimate.state/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.DirectClimate.html#t:state/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.DirectClimate.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.DirectClimate.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Emobility.Timer","doc":"Structure describing a vehicle timer.\n\nTimers are used to schedule charging, and/or to climatise (preheat/cool) the\nvehicle, e.g. in preparation for an upcoming trip.","ref":"PorscheConnEx.Struct.Emobility.Timer.html"},{"type":"module","title":"API calls - PorscheConnEx.Struct.Emobility.Timer","doc":"- To create or update a timer, use `PorscheConnEx.Client.put_timer/4`.\n- To delete a timer, use `PorscheConnEx.Client.delete_timer/4`.","ref":"PorscheConnEx.Struct.Emobility.Timer.html#module-api-calls"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Emobility.Timer","doc":"- `id` (integer) — the ID (slot number) of the timer (1 to 5)\n- `enabled?` (boolean) — whether the timer can trigger or not\n- `depart_time` (`NaiveDateTime`) — the local time the user intends to depart\n  - For repeating timers, this will be the next upcoming occurrence.\n- `repeating?` (boolean) — whether the event is a one-off (`false`) or repeats (`true`)\n- `weekdays` (list of integers, or `nil`) — a list indicating [ISO weekday numbers](`t:Calendar.ISO.day_of_week/0`)\n  - Repeating timers will occur at `NaiveDateTime.to_time(depart_time)` on every listed day.\n  - Non-repeating timers will have this set to `nil`.\n- `climate?` (boolean) — whether the timer will engage preheating / cooling\n- `charge?` (boolean) — whether the timer will charge the vehicle\n- `target_charge` (integer) — the target charge percentage (0 to 100)\n  - The official UIs limit you to 5% increments, but the API allows any value.\n\nNote that `depart_time` is the **end time** of charging / climatisation, and\n**not** the start time.  All activity will occur in the minutes prior to\n`depart_time`, on the assumption that this is when the user will actually want\na fully charged / climatised vehicle.\n\nThe actual start time will depend on several factors, including current\nbattery charge, current temperature, etc.  In particular, testing so far\nseems to indicates that climatisation timers will start sooner (i.e.\npreheat/cool for longer) if the vehicle is plugged in, since the vehicle is\nmore willing to spend wall power than battery power.  (It may even charge\nthe battery while doing so, ignoring any charge targets or preferred charging\nhours.)","ref":"PorscheConnEx.Struct.Emobility.Timer.html#module-fields"},{"type":"module","title":"Charging behaviour - PorscheConnEx.Struct.Emobility.Timer","doc":"For timers with `charge?` set to `true`, if the vehicle current charge level\nis below `target_charge` percent, it will attempt to bring the vehicle up to\n`target_charge` in time for `depart_time`.\n\nThe actual timing of the charge depends on the current [charging\nprofile](`PorscheConnEx.Struct.Emobility.ChargingProfile`), but in general,\nthe vehicle will wait until as late as possible to charge.\n\nThis means that if you have preferred charging hours set in your profile, and\nthe timer is outside of those hours, then charging will occur at the tail end\nof the those hours (for the block of hours immediately prior to\n`depart_time`).\n\nOtherwise, charging will occur immediately before `depart_time`.  (This may\nalso occur if you use the car and drain the battery between the preferred\ncharging hours and the timer, but I have not confirmed this.)","ref":"PorscheConnEx.Struct.Emobility.Timer.html#module-charging-behaviour"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.Timer.id/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.Timer.html#t:id/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.Timer.t/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.Timer.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Emobility.Timer.weekday/0","doc":"","ref":"PorscheConnEx.Struct.Emobility.Timer.html#t:weekday/0"},{"type":"module","title":"PorscheConnEx.Struct.Maintenance","doc":"Structure containing information about upcoming maintenance tasks.\n\nThis is the structure returned by `PorscheConnEx.Client.maintenance/2`.","ref":"PorscheConnEx.Struct.Maintenance.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Maintenance","doc":"- `schedule` (list of [`Maintenance.Task`](`Elixir.PorscheConnEx.Struct.Maintenance.Task`)) — a list of upcoming maintenance tasks\n- `service_access?` (boolean) — unknown\n\nNote that this structure is the least understood at the moment, since it\nchanges very slowly and is not easily probed or tested.  As such, you will\ncurrently find a lot of \"unknown\" labels in the nested maintenance sub-structures.","ref":"PorscheConnEx.Struct.Maintenance.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.t/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Maintenance.Task","doc":"Structure containing information about an upcoming maintenance task.","ref":"PorscheConnEx.Struct.Maintenance.Task.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Maintenance.Task","doc":"- `id` (string) — a four-digit ID code\n- `criticality` (integer) — unknown (always 1 in testing)\n  - Presumably some sort of priority sorting key.\n- `description` ([`Maintenance.Task.Description`](`Elixir.PorscheConnEx.Struct.Maintenance.Task.Description`)) — describes the task to be performed\n- `values` ([`Maintenance.Task.Values`](`Elixir.PorscheConnEx.Struct.Maintenance.Task.Values`)) — task metadata\n\nThese fields have always been `nil` in testing to date, so their datatype is currently not defined:\n\n- `remaining_days`\n- `remaining_km`\n- `remaining_percent`\n\nPresumably they'll likely be integers, floats, or unit structures.","ref":"PorscheConnEx.Struct.Maintenance.Task.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.t/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Maintenance.Task.Description","doc":"Structure containing descriptive information about a maintenance task.","ref":"PorscheConnEx.Struct.Maintenance.Task.Description.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Maintenance.Task.Description","doc":"- `short_name` (string) — the short name of the task\n  - e.g. \"TPMS battery (front left)\" or \"RDK-Batterie (vorne links)\"\n- `long_name` (string) — the long name of the task\n  - e.g. \"Replace TPMS battery (front left)\" or \"Wechsel der RDK-Batterie (vorne links)\"\n- `criticality` (integer) — seems to be a sentence describing whether maintenance is required?\n  - e.g. \"No maintenance is due at the moment.\" or \"Zurzeit ist kein Service notwendig.\"\n- `notification` (unknown) — always `nil` in testing\n  - Might be non-nil if maintenance is required?\n\nThe strings in this structure are heavily influenced by the session locale (see `PorscheConnEx.Config`).","ref":"PorscheConnEx.Struct.Maintenance.Task.Description.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Description.t/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Description.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Maintenance.Task.Values","doc":"Structure containing metadata about a maintenance task.","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Maintenance.Task.Values","doc":"- `model_id` (string) — a four-digit ID code\n  - Seems to generally be the same as the ID code of the containing task.\n- `model_state` (atom) — unknown\n  - only `:active` seen so far\n- `model_name` (string) — the name of the part to be replaced\n  - This is generally always in German, regardless of locale.\n- `model_visibility` (atom) — unknown\n  - only `:visible` seen so far\n- `source` (atom) — unknown\n  - only `:vehicle` seen so far\n- `event` (atom) — unknown\n  - only `:cyclic` seen so far\n- `odometer_last_reset` (integer) — unknown\n  - Might be the odometer reading when the task was last performed.\n- `criticality` (integer) — unknown\n  - Presumably some sort of priority sorting key.\n  - Seems to generally be the same as the criticality of the containing task.\n- `warnings` (map of `integer => integer`) — unknown\n  - In the raw data, these are represented as e.g. `\"WarnID294\" : \"0\"`.\n  - This gets translated into `294 => 0` in our `warnings` map.\n  - It's possible that the warning codes are UI localisation keys, and the values are whether to show them or not?  (No values other than `\"0\"` have been seen so far.)","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Values.event/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#t:event/0"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Values.model_state/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#t:model_state/0"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Values.model_visibility/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#t:model_visibility/0"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Values.source/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#t:source/0"},{"type":"type","title":"PorscheConnEx.Struct.Maintenance.Task.Values.t/0","doc":"","ref":"PorscheConnEx.Struct.Maintenance.Task.Values.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Overview","doc":"Structure containing overview information about a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.stored_overview/2`\nand `PorscheConnEx.Client.current_overview/2`.\n\nNote that there is significant overlap between this structure, `PorscheConnEx.Struct.Status`, and `PorscheConnEx.Struct.Emobility`.","ref":"PorscheConnEx.Struct.Overview.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Overview","doc":"- `vin` (string) — the 17-character Vehicle Identification Number\n- `car_model` (string ✱) — the vehicle platform code (e.g. \"J1\" for the Taycan)\n- `engine_type` (string ✱) — the type of propulsion system (e.g. \"BEV\")\n- `mileage` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the total distance the vehicle has travelled in its lifetime\n- `battery_level` ([`BatteryLevel`](`Elixir.PorscheConnEx.Struct.Unit.BatteryLevel`)) — the battery charge level of the vehicle\n- `charging_state` (atom ✱) — the battery charging state — `:off`, `:charging`, or `:completed`\n- `charging_status` (atom ✱) — a more detailed battery charging state\n  - `:unplugged` if the vehicle is not connected to a charging station\n  - `:init` if the vehicle is negotiating with the charging station to begin charging\n  - `:charging` if the vehicle is charging\n  - `:completed` if the vehicle has finished charging\n- `doors` ([`Overview.Doors`](`Elixir.PorscheConnEx.Struct.Overview.Doors`)) — the open/closed and locked/unlocked state of all doors\n  - contains 7 sub-fields\n- `windows` ([`Overview.Windows`](`Elixir.PorscheConnEx.Struct.Overview.Windows`)) — the open/closed state of all windows\n  - contains 7 sub-fields\n- `open?` (booelan) — the overall open/closed status of the vehicle\n  - This will be true if any door is unlocked, or any door/window is open.\n  - Ignores the status of the hood.\n- `tires` ([`Overview.Tires`](`Elixir.PorscheConnEx.Struct.Overview.Tires`)) — the pressure and status of all tires\n  - contains 4 sub-fields\n- `parking_brake?` (boolean) — whether the parking brake is engaged\n- `parking_brake_status` (unknown) — has always been `nil` in testing\n- `parking_light` (atom) — whether the `:left` or `:right` parking lights are engaged, or `:off`\n- `parking_light_status` (unknown) — has always been `nil` in testing\n- `parking_time` (`DateTime`) — the UTC time when the vehicle was last parked\n- `remaining_ranges` ([`Status.RemainingRanges`](`Elixir.PorscheConnEx.Struct.Status.RemainingRanges`)) — the estimated remaining travel ranges, by propulsion type\n  - contains 2 sub-fields\n- `service_intervals` (map of string to [`Status.ServiceInterval`](`Elixir.PorscheConnEx.Struct.Status.ServiceInterval`)) — upcoming service intervals\n  - Some entries map a string to `nil`, presumably to indicate no such service is requried.\n- `oil_level` (unknown) — my Taycan has no oil, this is `nil` for me\n- `fuel_level` (unknown) — my Taycan has no fuel, this is `nil` for me\n\nFields marked with \"✱\" may be `nil` when queried via [`current_overview/2`](`PorscheConnEx.Client.current_overview/2`).","ref":"PorscheConnEx.Struct.Overview.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Overview.charging_state/0","doc":"","ref":"PorscheConnEx.Struct.Overview.html#t:charging_state/0"},{"type":"type","title":"PorscheConnEx.Struct.Overview.charging_status/0","doc":"","ref":"PorscheConnEx.Struct.Overview.html#t:charging_status/0"},{"type":"type","title":"PorscheConnEx.Struct.Overview.parking_light/0","doc":"","ref":"PorscheConnEx.Struct.Overview.html#t:parking_light/0"},{"type":"type","title":"PorscheConnEx.Struct.Overview.t/0","doc":"","ref":"PorscheConnEx.Struct.Overview.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Overview.Doors","doc":"Structure detailing the open/closed and locked/unlocked state of all vehicle doors.","ref":"PorscheConnEx.Struct.Overview.Doors.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Overview.Doors","doc":"- `front_left` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`))\n- `front_right` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`))\n- `back_left` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`))\n- `back_right` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`))\n- `trunk` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`))\n- `hood` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`)) — always considered unlocked\n- `overall` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`)) — the overall status of the above (minus `hood`)","ref":"PorscheConnEx.Struct.Overview.Doors.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Overview.Doors.t/0","doc":"","ref":"PorscheConnEx.Struct.Overview.Doors.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Overview.TirePressure","doc":"Structure detailing the pressure and status of a single tire.","ref":"PorscheConnEx.Struct.Overview.TirePressure.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Overview.TirePressure","doc":"- `current` ([`Pressure`](`Elixir.PorscheConnEx.Struct.Unit.Pressure`) or `nil`) — the current tire pressure\n- `optimal` ([`Pressure`](`Elixir.PorscheConnEx.Struct.Unit.Pressure`) or `nil`) — the optimal tire pressure\n- `difference` ([`Pressure`](`Elixir.PorscheConnEx.Struct.Unit.Pressure`) or `nil`) - the difference between the above\n- `status` (atom) — the overall tire pressure status\n  - ***TODO:*** *I have not seen what value is returned when pressure is correct.*\n  - `:divergent` if the current pressure deviates from the optimal pressure.\n  - `nil` if tire pressure data is not available.\n\nThe Porsche tire pressure monitoring system requires that the vehicle be\nmoving.  When the vehicle is parked and does not have recent tire pressure\ndata, all of the above will be `nil`.","ref":"PorscheConnEx.Struct.Overview.TirePressure.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Overview.TirePressure.status/0","doc":"","ref":"PorscheConnEx.Struct.Overview.TirePressure.html#t:status/0"},{"type":"type","title":"PorscheConnEx.Struct.Overview.TirePressure.t/0","doc":"","ref":"PorscheConnEx.Struct.Overview.TirePressure.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Overview.Tires","doc":"Structure containing information about the pressure and status of all tires.","ref":"PorscheConnEx.Struct.Overview.Tires.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Overview.Tires","doc":"- `front_left` ([`Overview.TirePressure`](`Elixir.PorscheConnEx.Struct.Overview.TirePressure`))\n- `front_right` ([`Overview.TirePressure`](`Elixir.PorscheConnEx.Struct.Overview.TirePressure`))\n- `back_left` ([`Overview.TirePressure`](`Elixir.PorscheConnEx.Struct.Overview.TirePressure`))\n- `back_right` ([`Overview.TirePressure`](`Elixir.PorscheConnEx.Struct.Overview.TirePressure`))","ref":"PorscheConnEx.Struct.Overview.Tires.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Overview.Tires.t/0","doc":"","ref":"PorscheConnEx.Struct.Overview.Tires.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Overview.Windows","doc":"Structure containing information about the open/closed state of all windows.","ref":"PorscheConnEx.Struct.Overview.Windows.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Overview.Windows","doc":"- `front_left` (open status)\n- `front_right` (open status)\n- `back_left` (open status)\n- `back_right` (open status)\n- `maintenance_hatch` (open status)\n- `roof` (open status)\n- `sunroof` (struct)\n  - `position` (integer) — the sunroof open position as a percent value\n  - `status` (open status)\n\nAll \"open status\" fields will be either `:open`, `:closed`, or `nil` if not\npresent on the vehicle.","ref":"PorscheConnEx.Struct.Overview.Windows.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Overview.Windows.open_status/0","doc":"","ref":"PorscheConnEx.Struct.Overview.Windows.html#t:open_status/0"},{"type":"type","title":"PorscheConnEx.Struct.Overview.Windows.t/0","doc":"","ref":"PorscheConnEx.Struct.Overview.Windows.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Position","doc":"Structure containing the current global position data for a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.position/2`.","ref":"PorscheConnEx.Struct.Position.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Position","doc":"- `coordinates` (struct) — the vehicle's geographic coordinates\n  - `latitude` (float)\n  - `longitude` (float)\n  - `reference_system` (atom) — the coordinate reference system\n    - `:wgs84` is the only known value so far.\n- `heading` (integer) — the vehicle's compass heading\n  - Not currently known whether range would be 0 to 359, or 1 to 360.","ref":"PorscheConnEx.Struct.Position.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Position.coordinates/0","doc":"","ref":"PorscheConnEx.Struct.Position.html#t:coordinates/0"},{"type":"type","title":"PorscheConnEx.Struct.Position.ref_system/0","doc":"","ref":"PorscheConnEx.Struct.Position.html#t:ref_system/0"},{"type":"type","title":"PorscheConnEx.Struct.Position.t/0","doc":"","ref":"PorscheConnEx.Struct.Position.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Status","doc":"Structure containing overview information about a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.status/2`.\n\nNote that there is significant overlap between this structure and `PorscheConnEx.Struct.Overview`, and to a lesser degree, with `PorscheConnEx.Struct.Emobility`.","ref":"PorscheConnEx.Struct.Status.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Status","doc":"- `vin` (string) — the 17-character Vehicle Identification Number\n- `mileage` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the total distance the vehicle has travelled in its lifetime\n- `battery_level` ([`BatteryLevel`](`Elixir.PorscheConnEx.Struct.Unit.BatteryLevel`)) — the battery charge level of the vehicle\n- `remaining_ranges` ([`Status.RemainingRanges`](`Elixir.PorscheConnEx.Struct.Status.RemainingRanges`)) — the estimated remaining travel ranges, by propulsion type\n  - contains 2 sub-fields\n- `service_intervals` (map of string to [`Status.ServiceInterval`](`Elixir.PorscheConnEx.Struct.Status.ServiceInterval`)) — upcoming service intervals\n- `doors` ([`Status.LockStatus`](`Elixir.PorscheConnEx.Struct.Status.LockStatus`)) — the overall state of all vehicle doors\n- `oil_level` (unknown) — my Taycan has no oil, this is `nil` for me\n- `fuel_level` (unknown) — my Taycan has no fuel, this is `nil` for me","ref":"PorscheConnEx.Struct.Status.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Status.t/0","doc":"","ref":"PorscheConnEx.Struct.Status.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Status.LockStatus","doc":"Structure describing the open/closed and locked/unlocked status of a vehicle door.","ref":"PorscheConnEx.Struct.Status.LockStatus.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Status.LockStatus","doc":"- `open?` (boolean) — whether the door is physically open\n- `locked?` (boolean) — whether the door is locked to prevent it opening\n\nNote that while the vehicle hood also uses this structure, it is always\nconsidered unlocked, and is not counted in the overall locked/unlocked state\nof the vehicle.","ref":"PorscheConnEx.Struct.Status.LockStatus.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Status.LockStatus.t/0","doc":"","ref":"PorscheConnEx.Struct.Status.LockStatus.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Status.Range","doc":"Structure describing the estimated travel distance available for a\ngiven propulsion system.\n\nUsed in `PorscheConnEx.Struct.Status.RemainingRanges` structures.","ref":"PorscheConnEx.Struct.Status.Range.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Status.Range","doc":"- `engine_type` (atom) — the type of vehicle propulsion system\n  - `:electric` for battery-electric propulsion\n  - ***TODO:*** *determine value for conventional engines*\n  - `nil` if this propulsion method is not supported by this vehicle\n- `primary?` (boolean) — whether this is the vehicle's primary propulsion system\n  - Only appears in [`Overview`](`Elixir.PorscheConnEx.Struct.Overview`) requests, not in [`Status`](`Elixir.PorscheConnEx.Struct.Status`) requests.\n- `distance` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the estimated reamining travel distance available","ref":"PorscheConnEx.Struct.Status.Range.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Status.Range.engine_type/0","doc":"","ref":"PorscheConnEx.Struct.Status.Range.html#t:engine_type/0"},{"type":"type","title":"PorscheConnEx.Struct.Status.Range.t/0","doc":"","ref":"PorscheConnEx.Struct.Status.Range.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Status.RemainingRanges","doc":"Structure describing the estimated travel distance available for all propulsion systems.\n\nUsed in `PorscheConnEx.Struct.Status` and `PorscheConnEx.Struct.Overview` structures.","ref":"PorscheConnEx.Struct.Status.RemainingRanges.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Status.RemainingRanges","doc":"- `electric` ([`Status.Range`](`Elixir.PorscheConnEx.Struct.Status.Range`)) — the estimated remaining battery-electric range\n- `conventional` ([`Status.Range`](`Elixir.PorscheConnEx.Struct.Status.Range`)) — the estimated remaining fuel-burning range","ref":"PorscheConnEx.Struct.Status.RemainingRanges.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Status.RemainingRanges.t/0","doc":"","ref":"PorscheConnEx.Struct.Status.RemainingRanges.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Status.ServiceInterval","doc":"Structure describing an upcoming recommended service interval.\n\nUsed in `PorscheConnEx.Struct.Status` and `PorscheConnEx.Struct.Overview` structures.","ref":"PorscheConnEx.Struct.Status.ServiceInterval.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Status.ServiceInterval","doc":"- `distance` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`) or `nil`) — the remaining distance before service is recommended\n- `time` ([`Time`](`Elixir.PorscheConnEx.Struct.Unit.Time`) or `nil`) — the remaining time before service is recommended\n\nIf a vehicle does not require a particular kind of service — for example, an\n\"oil service\" for a vehicle without oil — then all fields will be `nil`.","ref":"PorscheConnEx.Struct.Status.ServiceInterval.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Status.ServiceInterval.t/0","doc":"","ref":"PorscheConnEx.Struct.Status.ServiceInterval.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Summary","doc":"Structure containing extremely basic information about a particular vehicle.\n\nThis is the structure returned by `PorscheConnEx.Client.summary/2`.","ref":"PorscheConnEx.Struct.Summary.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Summary","doc":"- `model_description` (string) — the vehicle model description (e.g. \"Taycan GTS\")\n- `nickname` (string or `nil`) — the user-assigned nickname for the vehicle (if set)","ref":"PorscheConnEx.Struct.Summary.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Summary.t/0","doc":"","ref":"PorscheConnEx.Struct.Summary.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Trip","doc":"Structure containing trip data — distance, speed, efficiency, etc.\n\nThis is the structure returned by `PorscheConnEx.Client.trips_short_term/2`\nand `PorscheConnEx.Client.trips_long_term/2`.","ref":"PorscheConnEx.Struct.Trip.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Trip","doc":"- `id` (integer) — the internal trip ID\n- `type` (atom) — the type of trip\n  - `:short_term` for `trips_short_term/2` calls\n  - `:long_term` for `trips_long_term/2` calls\n- `timestamp` (`DateTime`) — the UTC timestamp the trip ended at\n- `minutes` (integer) — the duration of the trip, in minutes\n- `start_mileage` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the total vehicle miles travelled prior to this trip\n- `end_mileage` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the total vehicle miles travelled at the end of this trip\n- `distance` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — the distance travelled during this trip\n- `average_speed` ([`Speed`](`Elixir.PorscheConnEx.Struct.Unit.Speed`)) — the average speed during the trip\n  - This should generally be similar to `distance / minutes`, although there appears to be some rounding.\n- `zero_emission_distance` ([`Distance`](`Elixir.PorscheConnEx.Struct.Unit.Distance`)) — distanc travelled using a zero-emission energy source (e.g. battery)\n- `average_fuel_consumption` ([`Consumption.Fuel`](`Elixir.PorscheConnEx.Struct.Unit.Consumption.Fuel`)) — average fuel efficiency during the trip\n- `average_energy_consumption` ([`Consumption.Energy`](`Elixir.PorscheConnEx.Struct.Unit.Consumption.Energy`)) — average energy efficiency during the trip","ref":"PorscheConnEx.Struct.Trip.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Trip.t/0","doc":"","ref":"PorscheConnEx.Struct.Trip.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.BatteryLevel","doc":"Structure representing battery charge level.","ref":"PorscheConnEx.Struct.Unit.BatteryLevel.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.BatteryLevel","doc":"- `unit` (atom) — only known value is `:percent`\n- `value` (integer) — percentage of full\n\nIt's a bit of a silly unit, since it could just be replaced by an integer\npercentage.  In fact, \"emobility\" calls do exactly that; this structure is\nonly used in \"status\" and \"overview\" calls.\n\nI assume it's just used for app/web UI presentation purposes, but maybe\nthere's some other nuance I'm not aware of.","ref":"PorscheConnEx.Struct.Unit.BatteryLevel.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.BatteryLevel.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.BatteryLevel.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.BatteryLevel.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.BatteryLevel.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.ChargeRate","doc":"Structure representing rate of battery charge in terms of distance gained per unit time.","ref":"PorscheConnEx.Struct.Unit.ChargeRate.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.ChargeRate","doc":"- `unit` (atom) — units used, depends on locale\n  - `:km_per_minute` — kilometres gained per minute of charge\n  - `:mi_per_minute` — miles gained per minute of charge\n- `value` (float) — value in above units\n- `km_per_hour` — kilometres gained per hour of charge\n\nLike most units in this API, a normalised value (`km_per_hour`) is included,\nregardless of locale settings.","ref":"PorscheConnEx.Struct.Unit.ChargeRate.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.ChargeRate.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.ChargeRate.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.ChargeRate.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.ChargeRate.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Consumption.Energy","doc":"Structure representing a ratio of energy consumed versus distance travelled.","ref":"PorscheConnEx.Struct.Unit.Consumption.Energy.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Consumption.Energy","doc":"- `unit` (atom) — units used, depends on locale\n  - `:kwh_per_100km` — kilowatt-hours per hundred kilometres (kWh/100km)\n  - `:miles_per_kwh` - miles per kilowatt-hour (mi/kWh)\n- `value` (float) — value in above units\n- `kwh_per_100km` (float) — kWh/100km equivalent\n\nNote that the ratios are inverted for metric versus imperial — metric is\nenergy per unit of distance travelled (and lower numbers are more efficient),\nwhile imperial is distance travelled per unit of energy (and higher numbers are\nmore efficient).\n\nLike most units in this API, a normalised value (`kwh_per_100km`) is\nincluded, regardless of locale settings.\n\nGiven the numbers returned by the API, it's pretty clear that the values are\nstored in kWh/100km (rounded to one decimal of precision), and are converted\nto mi/kWh for imperial locales.","ref":"PorscheConnEx.Struct.Unit.Consumption.Energy.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Consumption.Energy.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Consumption.Energy.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Consumption.Energy.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Consumption.Energy.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Consumption.Fuel","doc":"Structure representing a ratio of fuel consumed versus distance travelled.","ref":"PorscheConnEx.Struct.Unit.Consumption.Fuel.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Consumption.Fuel","doc":"- `unit` (atom) — units used, depends on locale\n  - `:litres_per_100km` — litres of fuel per hundred kilometres (L/100km)\n  - `:miles_per_gallon` - miles per gallon of fuel (mpg)\n- `value` (float) — value in above units\n- `litres_per_100km` (float) — L/100km equivalent\n\nNote that the ratios are inverted for metric versus imperial — metric is fuel\nper unit of distance travelled (and lower numbers are more efficient), while\nimperial is distance travelled per unit of fuel (and higher numbers are more\nefficient).\n\nLike most units in this API, a normalised value (`litres_per_100km`) is\nincluded, regardless of locale settings.\n\nSince my car does not use fuel, I cannot report on the original unit or the\nexpected precision of fuel consumption values.  However, if this unit follows\nthe trend of other units in this API, it's likely that the metric value is\nthe original precise value, and the imperial value is a conversion of that.","ref":"PorscheConnEx.Struct.Unit.Consumption.Fuel.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Consumption.Fuel.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Consumption.Fuel.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Consumption.Fuel.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Consumption.Fuel.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Distance","doc":"Structure representing units of distance.","ref":"PorscheConnEx.Struct.Unit.Distance.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Distance","doc":"- `unit` (atom) — units used, depends on locale\n  - `:km` — kilometres\n  - `:mi` — miles\n- `value` (float) — value in above units\n- `km` (float) — kilometres equivalent\n\nLike most units in this API, a normalised value (`km`) is included,\nregardless of locale settings.","ref":"PorscheConnEx.Struct.Unit.Distance.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Distance.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Distance.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Distance.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Distance.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Pressure","doc":"Structure representing units of pressure.","ref":"PorscheConnEx.Struct.Unit.Pressure.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Pressure","doc":"- `unit` (atom) — units used, depends on locale\n  - `:bar` — bar\n  - `:psi` — pounds per square inch\n- `value` (float) — value in above units\n- `bar` (float) — equivalent value in bar\n\nLike most units in this API, a normalised value (`bar`) is included,\nregardless of locale settings.\n\nGiven the numbers returned by the API, it's pretty clear that the values are\nare stored in bar (with one decimal of precision), and are converted to PSI\nfor imperial locales.","ref":"PorscheConnEx.Struct.Unit.Pressure.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Pressure.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Pressure.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Pressure.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Pressure.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Speed","doc":"Structure representing units of speed.","ref":"PorscheConnEx.Struct.Unit.Speed.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Speed","doc":"- `celsius` (atom) — units used, depends on locale\n  - `:km_per_hour` — kilometres per hour (km/h)\n  - `:mi_per_hour` — miles per hour (mph)\n- `value` (float) — value in above units\n- `km_per_hour` (float) — equivalent value in kilometres per hour\n\nLike most units in this API, a normalised value (`km_per_hour`) is included,\nregardless of locale settings.\n\nGiven the numbers returned by the API, it's pretty clear that the values are\nstored in km/h (rounded to whole numbers), and are converted to miles per\nhour for imperial locales.","ref":"PorscheConnEx.Struct.Unit.Speed.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Speed.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Speed.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Speed.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Speed.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Temperature","doc":"Structure representing temperature.","ref":"PorscheConnEx.Struct.Unit.Temperature.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Temperature","doc":"- `celsius` (float) — temperature in degrees Celsius (°C) with one decimal precision\n- `decikelvin` (integer) — temperature in tenths of degrees Kelvin (dK)\n\nThe API only provides `decikelvin`, but this library provides a `celsius`\nvalue for convenience, since conversion is simple and precise.  Note that\nPorsche considers 0°C to be equivalent to 273 K, rather than the more\naccurate 273.15 K.\n\nDecikelvin is reportedly a common integer unit for industrial\nsensors, which is likely why Porsche uses this unit internally.","ref":"PorscheConnEx.Struct.Unit.Temperature.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Temperature.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Temperature.html#t:t/0"},{"type":"module","title":"PorscheConnEx.Struct.Unit.Time","doc":"Structure representing time.\n\nCurrently only used in `PorscheConnEx.Struct.Status.ServiceInterval`.","ref":"PorscheConnEx.Struct.Unit.Time.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Unit.Time","doc":"- `unit` (atom) — unit of time\n  - only known value is `:day`\n- `value` (integer) — number of above units","ref":"PorscheConnEx.Struct.Unit.Time.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Time.t/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Time.html#t:t/0"},{"type":"type","title":"PorscheConnEx.Struct.Unit.Time.unit/0","doc":"","ref":"PorscheConnEx.Struct.Unit.Time.html#t:unit/0"},{"type":"module","title":"PorscheConnEx.Struct.Vehicle","doc":"Structure containing information about a vehicle attached to an API account.\n\nThis is the structure returned by `PorscheConnEx.Client.vehicles/1`.","ref":"PorscheConnEx.Struct.Vehicle.html"},{"type":"module","title":"Fields - PorscheConnEx.Struct.Vehicle","doc":"- `vin` (string) — the 17-character Vehicle Identification Number\n- `pcc?` (boolean) — (presumably?) whether the vehicle has the Porsche Car Connect service\n- `relationship` (string) — the user's relationship to the vehicle\n  - only known value is \"OWNER\"\n- `model_description` (string) — the vehicle model description, e.g. \"Taycan GTS\"\n- `model_type` (string) — the internal code for the model, e.g. \"Y1ADE1\"\n- `model_year` (integer) — the vehicle model year\n- `exterior_color` (string) — the vehicle colour by name, e.g. \"vulkangraumetallic/vulkangraumetallic\"\n- `exterior_color_hex` (string) — the vehicle colour by its HTML RGB hex code\n- `spin_enabled?` (boolean) — unknown\n- `login_method` — (presumably?) how the vehicle logged in to the user's account\n- `ota_active?` — (presumably?) whether the vehicle is receiving over-the-air updates\n- `attributes` (map of `string => string`) — extra vehicle metadata\n  - if the vehicle has a nickname set, this will appear as `\"licenseplate\" => nickname`\n- `pending_relationship_termination_at` (unknown) - nil for me, but likely a `DateTime`?","ref":"PorscheConnEx.Struct.Vehicle.html#module-fields"},{"type":"type","title":"PorscheConnEx.Struct.Vehicle.t/0","doc":"","ref":"PorscheConnEx.Struct.Vehicle.html#t:t/0"},{"type":"extras","title":"PorscheConnEx","doc":"# PorscheConnEx\n\nPorscheConnEx is a library for connecting to the Porsche Connect API, to monitor and control your Porsche vehicle.","ref":"readme.html"},{"type":"extras","title":"Installation - PorscheConnEx","doc":"PorscheConnEx requires Elixir v1.15 or later.  To use it, add `:porsche_conn_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:porsche_conn_ex, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - PorscheConnEx","doc":"```elixir\n# Start a PorscheConnEx session:\n{:ok, pid} = PorscheConnEx.Session.start_link(credentials: %{\n  username: \"user@domain.com\", \n  password: \"my_password\"\n}, name: MySession)\n\n# Get a list of vehicles:\n{:ok, vehicles} = PorscheConnEx.Client.vehicles(pid)\n\n# Get a summary of the first vehicle (and output it):\nvin = List.first(vehicles).vin\n{:ok, summary} = PorscheConnEx.Client.summary(pid, vin)\nsummary |> IO.inspect(label: \"Summary\")\n\n# Get the vehicle model:\n{:ok, capabilities} = PorscheConnEx.Client.capabilities(pid, vin)\nmodel = capabilities.car_model\n\n# Get the current emobility data:\n{:ok, emobility} = PorscheConnEx.Client.emobility(pid, vin, model)\n\n# Output the current battery charge and estimated remaining distance:\nemobility.charging.percent |> IO.inspect(label: \"Percent charged\")\nemobility.charging.remaining_electric_range |> IO.inspect(label: \"Remaining range\")\n\n# There's a lot of overlap in the various API calls -- you can get the same\n# data via both `status/2` and `stored_overview/2`.  For example:\n{:ok, status} = PorscheConnEx.Client.status(pid, vin)\n{status.battery_level, status.remaining_ranges.electric.distance} |> IO.inspect(label: \"Status\")\n\n# If you want the most current data, you can use `current_overview/2`, but it's slowww:\n{:ok, pending} = PorscheConnEx.Client.current_overview(pid, vin)\n{:ok, overview} = PorscheConnEx.Client.wait(pid, pending)\n{overview.battery_level, overview.remaining_ranges.electric.distance} |> IO.inspect(label: \"Overview\")\n\n# And since we named the process `MySession`, we can use that instead:\n{:ok, position} = PorscheConnEx.Client.position(MySession, vin)\nposition.coordinates |> IO.inspect(label: \"Position\")\n```\n\nOutput:\n\n```elixir\nSummary: %PorscheConnEx.Struct.Summary{model_description: \"Taycan GTS\", nickname: nil}\nPercent charged: 80\nRemaining range: #PorscheConnEx.Struct.Unit.Distance<261.0 km>\nStatus: {#PorscheConnEx.Struct.Unit.BatteryLevel<80%>, #PorscheConnEx.Struct.Unit.Distance<261.0 km>}\nOverview: {#PorscheConnEx.Struct.Unit.BatteryLevel<80%>, #PorscheConnEx.Struct.Unit.Distance<261.0 km>}\nPosition: %PorscheConnEx.Struct.Position.Coordinates{\n  latitude: 45.678901,\n  longitude: -76.543210,\n  reference_system: :wgs84\n}\n```","ref":"readme.html#usage"},{"type":"extras","title":"Documentation - PorscheConnEx","doc":"Full documentation can be found at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Legal stuff - PorscheConnEx","doc":"Copyright © 2024, Adrian Irving-Beer.\n\nPorscheConnEx is released under the [MIT license](https://github.com/wisq/porsche_conn_ex/blob/main/LICENSE) and is provided with **no warranty**.  Use this code at your own risk, and be careful with what commands you issue to your (insanely expensive) vehicle.\n\nPorscheConnEx is in no way associated with, or endorsed by, Porsche or any of their subsidiaries or associated companies.  \"Porsche\" and \"Taycan\" are registered trademarks of Porsche, and their use in this library are only for the purposes of identifying and describing those products.  The API this library uses is unofficial and undocumented, and is subject to change at any time and without warning, potentially breaking this library.","ref":"readme.html#legal-stuff"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"* Initial release.","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}